@@ -54,7 +54,8 @@ assign(".rgdal_old.GDAL_DATA", "", envir=.RGDAL_CACHE)
     ifelse(GDAL_iconv(), "",
         paste(" GDAL does not use iconv for recoding strings.\n")),
     ' Loaded PROJ.4 runtime: ', getPROJ4VersionInfo(), '\n',
-    paste(" Path to PROJ.4 shared files: ", pl[1], sep=""), "\n", sep="")
+    paste(" Path to PROJ.4 shared files: ", pl[1], sep=""), "\n",
+    ifelse(get("has_proj_def.dat", envir=.RGDAL_CACHE), "", "WARNING: no proj_defs.dat in PROJ.4 shared files\n"), sep="")
     splVersion <- version_sp_linkingTo()
   Smess <- paste(Smess, "Linking to sp version:", splVersion, "\n")
   spVcheck <- NULL
